export function formatDate(dateString: string | number) {
    // Making sure it parses both dates with and without times
    const dateObj = new Date(dateString);
    const full = `${dateObj.toLocaleString('en-US', {
        month: "short",
    })} ${dateObj.getDate()}, ${dateObj.getFullYear()}`;
    const month = dateObj.toLocaleString('en-US', {
        month: "short",
    });
    return {
        full,
        month,
        day: dateObj.getDate(),
        year: dateObj.getFullYear(),
        monthDayWithTimestamp: `${month} ${dateObj.getDate()}, \n ${dateObj.toLocaleTimeString('en-US')}`,
        fullWithTimestamp: `${full}, ${dateObj.toLocaleTimeString('en-US')}`,
        fullWithUSTimestamp: `${full}, ${dateObj.toLocaleTimeString('en-US', { hour: '2-digit', minute: '2-digit' })}`,
    };
}

export function formatDateRange(dates: string[]) {
    if (dates.length < 2) {
        throw new Error("Expected an array of two dates for a range.");
    }

    const startDate = formatDate(dates[0]);
    const endDate = formatDate(dates[1]);
    let dateRange;
    if (startDate.year === endDate.year) {
        if (startDate.month === endDate.month) {
            dateRange = `${startDate.month} ${startDate.day} - ${endDate.day}, ${endDate.year}`;
        } else {
            dateRange = `${startDate.month} ${startDate.day} - ${endDate.month} ${endDate.day}, ${endDate.year}`;
        }
    } else {
        dateRange = `${startDate.full} - ${endDate.full}`;
    }

    return dateRange;
}

export function formatNumbers(value: number | string) {
    if (typeof value == 'string') {
        value = parseFloat(value)
    }
    return new Intl.NumberFormat('en-US').format(value)
}
export function roundNumber(value: number) {
    return new Intl.NumberFormat("en-US", { maximumSignificantDigits: 3 }).format(
        value)
}
export const labelsStyle = {
    color: "#666",
    fontSize: 14,
    fontFamily: "SourceSansPro",
    fontStyle: "normal",
    fontWeight: "600",
    lineHeight: 18,
    formatter: (value: number| string) => {
        const label = formatNumbers(value);
        return label == 'NaN' ? value : label;
    },
};
