import dataiku
import pandas as pd

# Initialize cumulative totals and count
cumulative_totals = None
cumulative_count = 0

# Read data in chunks
product_database_prepared_filtered = dataiku.Dataset("product_database_prepared_filtered")

for chunk in product_database_prepared_filtered.iter_dataframes(chunksize=10000):
    # Initialize cumulative totals with the columns of the first chunk
    if cumulative_totals is None:
        cumulative_totals = pd.Series(0, index=chunk.columns)

    # Update totals and count
    cumulative_totals += chunk.notnull().sum()
    cumulative_count += len(chunk)

# Calculate percentages
total_rows = cumulative_count
missing_values = total_rows - cumulative_totals
empty_values_percentage = (missing_values / total_rows) * 100
empty_values_percentage = round(empty_values_percentage, 2)

# Create a dataframe to store results
result = pd.DataFrame({'Column': missing_values.index, 'empty_values_percentage': empty_values_percentage})

# Write the result to a Dataiku dataset
percent_missing_values = dataiku.Dataset("missing_values_report")
percent_missing_values.write_with_schema(result)